@@ -409,8 +409,8 @@ it is started."
     (save-excursion
       (goto-char utop-prompt-min)
       (forward-line -1)
-      (let ((line (replace-in-string (thing-at-point 'line) "\n" "")))
-        (set-text-properties 0 (length line) nil line)
+      (let ((line (buffer-substring-no-properties
+                   (line-beginning-position) (line-end-position))))
         (message line)))))
 
 ;; Poor man's identifier at point
@@ -1156,7 +1156,10 @@ defaults to 0."
 
 (defun utop-setup-ocaml-buffer ()
   "Deprecated"
-  (error "This function is deprecated. See https://github.com/diml/utop for configuration information."))
+  (error "`utop-setup-ocaml-buffer' is deprecated, you need to
+replace it by `utop-minor-mode'.
+
+See https://github.com/diml/utop for configuration information."))
 
 ;;;###autoload
 (define-minor-mode utop-minor-mode
